from setuptools import setup, find_packages

setup(
    name='fwdprop',
    version='0.1.3',
    packages=find_packages(),
    install_requires=[],
    author='Gokulanand M',  # <<-- YOUR NAME
    author_email='youremail@example.com',  # <<-- YOUR EMAIL
    description='A simple forward propagation simulator for neural networks',
)
